/* Created by Anjuta version 1.0.2 */
/*	This file will not be overwritten */
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <gtk/gtk.h>
#include <locale.h>

#include "topwin.h"
#include "anthy.h"
#include "intl.h"

static TopWindow *mainwindow = NULL;

int make_gui(void) {	
    mainwindow = g_malloc(sizeof(TopWindow));
    create_topwindow(mainwindow);
    show_topwindow(mainwindow);
    return 1;
}

void clean_gui(void) {
    g_free(mainwindow);
}

gint main(gint argc, gchar *argv[]) {
    setlocale(LC_ALL, "");
    bindtextdomain(PACKAGE, LOCALEDIR);
    bind_textdomain_codeset(PACKAGE, "UTF-8");
    textdomain(PACKAGE);
    
    gtk_init(&argc, &argv);
    make_gui();
    
    gtk_main();
    clean_gui();
    return (0);
}
